Description Usage Arguments Examples
This function reads in CSVs and allows you to specify certain columns to import. It is faster than fread when selecting specific columns.
1 |
data |
the path/name of csv you wish to read in (same format as you would use for read.csv) |
select |
list of column names you wish you bring in (i.e. c("COLUMN1", "COLUMN3")). If you run without a select statement, creed will return a data frame with a data frame of all the column names so you can figure out what columns exist in the csv |
1 2 3 4 5 6 7 8 9 | #run without select statement to get column names:
raw.data <- system.file("extdata", "DATA.csv", package = "creed", mustWork = TRUE)
print(creed(raw.data))
#run with select statement to get specific columns:
raw.data <- system.file("extdata", "DATA.csv", package = "creed", mustWork = TRUE)
print(creed(raw.data, select = c("COLUMN1", "COLUMN3")))
#run with select = "ALL" to get all columns:
raw.data <- system.file("extdata", "DATA.csv", package = "creed", mustWork = TRUE)
print(creed(raw.data, select = "ALL"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.